"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const path = require("path");
const fs = require("fs-extra");
const colors = require("colors");
const child_process_1 = require("child_process");
function runScript(script, cwd) {
    return __awaiter(this, void 0, void 0, function* () {
        yield new Promise((resolve, reject) => {
            let exists = false;
            const child = child_process_1.exec(script, { cwd: cwd });
            child.stdout.on('data', (data) => {
                console.log(data);
            });
            child.stderr.on('data', (data) => {
                console.error(data);
            });
            child.once('exit', () => {
                child.stdout.removeAllListeners();
                child.stderr.removeAllListeners();
                resolve(exists);
            });
        });
    });
}
function initProject(projectName, templateType = 'ts') {
    return __awaiter(this, void 0, void 0, function* () {
        const parsed = path.parse(projectName);
        const name = parsed.name;
        let pathToProject = path.join(process.cwd(), parsed.name);
        console.log(colors.green(`Creating your new ROS project: "${name}"`));
        if (yield fs.pathExists(pathToProject)) {
            console.error(colors.red(`Oh no! The directory ${pathToProject} already exists.`));
            process.exit(0);
            return;
        }
        let templateProjectDir = path.join(__dirname, '../templates/js/');
        if (templateType === 'ts') {
            templateProjectDir = path.join(__dirname, '../templates/ts/');
        }
        yield fs.mkdirp(pathToProject);
        yield fs.copy(templateProjectDir, pathToProject, { recursive: true });
        let installScript = `npm install --save-exact realm-object-server`;
        let generalInstall = `npm install`;
        yield runScript(installScript, pathToProject);
        yield runScript(generalInstall, pathToProject);
    });
}
exports.initProject = initProject;
//# sourceMappingURL=project.js.map